#!/bin/bash

# configbase contains:
#
# C_FILE = config filename
# C_MAP = serverMap
# C_DIR = Save Directory Name (must be unique!)
# C_NAME = Server Name
#
# C_RPORT = RCONPort
# C_PORT = Port
# C_QPORT = QueryPort
# C_SMODS = CSV of any special mods
#

source common/$commonconfig
source common/$eventconfig

for i in `ls configbase/*.basecfg`; do
	source $i

	if [[ $C_FILE ]]; then
		$OUT = "out/$C_FILE"
		echo "Creating file $OUT..."

		echo "# Configuration file for $C_FILE" > $OUT
		echo "arkserverroot=$C_ARKSERVERROOT" >> $OUT
		echo "" >> $OUT

		echo "# Server Configuration" >> $OUT
		echo "serverMap=\"$C_MAP\"" >> $OUT
		echo "ark_SessionName='$C_NAME'" >> $OUT
		echo "ark_RCONEnabled=\"True\"" >> $OUT
		echo "ark_RCONPort=\"$C_RPORT\"" >> $OUT
		echo "ark_Port=\"$C_PORT\"" >> $OUT
		echo "ark_QuertyPort=\"$C_PORT\"" >> $OUT
		echo "" >> $OUT
		echo "ark_ServerPassword=\"\"" >> $OUT 		#there is no server password
		echo "ark_ServerAdminPassword=\"$C_PASSWORD\" >> $OUT
		echo "" >> $OUT
		echo "ark_MaxPlayers=\"70\"" >> $OUT
		if [[ -n "$C_SMODS" ]]; then
			echo "ark_GameModIds=\"$C_MODS,$C_SMODS\"" >> $OUT
		else
			echo "ark_GameModIds=\"$C_MODS\"" >> $OUT
		fi
		echo "ark_AltSaveDirectoryName=\"$C_DIR\"" >> $OUT
		echo "ark_AlwaysRestartOnCrash=true" >> $OUT
		echo "ark_noTributeDownloads=false" >> $OUT
		echo "ark_ServerPVE=\"true\" >> $OUT
		echo "" >> $OUT

		echo "# Cluster Config" >> $OUT
		echo "arkflag_NoTransferFromFiltering=\"\"" >> $OUT
		echo "arkopt_clusterid=\"astncluster\"" >> $OUT
		echo "arkopt_clusterClusterDirectoryOverride=\"$C_CLUSTERDIR\"" >> $OUT
		echo "" >> $OUT

		echo "# Game INI Configs" >> $OUT
		echo "ark_bAllowPlatformSaddleMultiFloors=true" >> $OUT
		echo "ark_bAllowUnlimitedRespecs=true" >> $OUT
		echo "ark_PreventOfflinePvP=False" >> $OUT
		echo "ark_AllowFlyerCarryPvE=True" >> $OUT
		echo "" >> $OUT

		echo "# Flags" >> $OUT
		echo "arkflag_noundermeshchecking=\"\"" >> $OUT
		echo "arkflag_crossplay=\"\"" >> $OUT		#crossplay isn't even supported on modded servers...why do we have this?
		echo "arkflag_ForceAllowCaveFlyers=\"true\"" >> $OUT
		echo "arkflag_alwaysNotifyPlayerJoined=\"true\"" >> $OUT
		echo "arkflag_alwaysNotifyPlayerLeft=\"true\"" >> $OUT
		echo "" >> $OUT

		echo "# ActiveEvent" >> $OUT
		if [[ -n "$C_EVENT" ]]; then
			echo "arkopt_ActiveEvent=\"$C_EVENT\"" >> $OUT
		else
			echo "# // NONE ACTIVE //" >> $OUT
	else
		echo "Cannot create config for $i, incorrectly configured"
	fi
done
